@@ -7,8 +7,8 @@ use Mojo::Base 'Mojolicious::Command';
 use Path::Tiny;
 use DateTime;
 use App::skryf::Util;
-
-our $VERSION = '0.005_01'; # VERSION
+use Data::Dump qw[pp];
+our $VERSION = '0.001'; # VERSION
 
 has description => "Create blog post.\n";
 has usage => <<"EOF";
